@@ -253,6 +253,26 @@ class HeatMap(Provider):
         self.clear_flag = 1 if self.clear_flag == 0 else 0
 
 
+class IML(Provider):
+    """IML Provider class.
+
+    Provider for fetching data from Interactive Map Layer.
+
+    Attributes
+    ----------
+    catalog_hrn: string
+        Catalog HRN.
+    layer_id: string
+        Id of interactive map layer.
+    """
+
+    _view_name = Unicode("IMLView").tag(sync=True)
+    _model_name = Unicode("IMLModel").tag(sync=True)
+
+    catalog_hrn = Unicode().tag(sync=True)
+    layer_id = Unicode().tag(sync=True)
+
+
 class Layer(Widget):
     """Layer class
 
@@ -266,6 +286,8 @@ class Layer(Widget):
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
+    name = Unicode("").tag(sync=True)
+
 
 class TileLayer(Layer):
     """Tile layer class
@@ -1447,6 +1469,53 @@ class MapSettingsControl(Control):
     basemaps = List(trait=Unicode()).tag(sync=True)
     layers = List(Dict()).tag(trait=Instance(Layer), sync=True, **widget_serialization)
 
+    _layer_ids = List()
+
+    @validate("layers")
+    def _validate_layers(self, proposal):
+        """Validate layers list.
+
+        Makes sure only one instance of any given layer can exist in the
+        layers list.
+        """
+        self._layer_ids = [lr["layer"].model_id for lr in proposal.value]
+        if len(set(self._layer_ids)) != len(self._layer_ids):
+            raise Exception("duplicate layer detected, only use each layer once")
+        return proposal.value
+
+    def add_layers(self, layers):
+        """Add layers to map."""
+        for layer in layers:
+            if layer["layer"].model_id in self._layer_ids:
+                raise Exception("layer already on map: %r" % layer)
+        self.layers = tuple([lr for lr in self.layers] + layers)
+
+    def remove_layers(self, layers):
+        """Remove layers from map."""
+        for layer in layers:
+            if layer["layer"].model_id not in self._layer_ids:
+                raise Exception("layer not on map: %r" % layer)
+
+        remove_layer_ids = set([lr["layer"].model_id for lr in layers])
+        self.layers = tuple(
+            [lyr for lyr in self.layers if lyr["layer"].model_id not in remove_layer_ids]
+        )
+
+    def __iadd__(self, item):
+        if isinstance(item, list):
+            self.add_layers(item)
+        return self
+
+    def __isub__(self, item):
+        if isinstance(item, list):
+            self.remove_layers(item)
+        return self
+
+    def __add__(self, item):
+        if isinstance(item, list):
+            self.add_layers(item)
+        return self
+
 
 class WidgetControl(Control):
     """WidgetControl class
@@ -1462,6 +1531,8 @@ class WidgetControl(Control):
         defaults to RIGHT_BOTTOM.
     widget: object
         ipywidget object to be added on the map.
+    transparent_bg: bool
+        If set to ``True`` widget will be added as transparent on Map.
     """
 
     _view_name = Unicode("WidgetControlView").tag(sync=True)
@@ -1470,6 +1541,7 @@ class WidgetControl(Control):
     name = Unicode("WidgetControl").tag(sync=True)
     alignment = Unicode("RIGHT_BOTTOM").tag(sync=True)
     widget = Instance(DOMWidget).tag(sync=True, **widget_serialization)
+    transparent_bg = Bool(False).tag(sync=True)
 
 
 class FullscreenControl(Control):
@@ -1631,6 +1703,19 @@ class SplitMapControl(Control):
     )
 
 
+class LayersControl(Control):
+    """LayersControl class.
+
+    A control which allows hiding/showing different layers on the Map.
+    """
+
+    _view_name = Unicode("LayersControlView").tag(sync=True)
+    _model_name = Unicode("LayersControlModel").tag(sync=True)
+
+    name = Unicode("LayersControl").tag(sync=True)
+    alignment = Unicode("RIGHT_TOP").tag(sync=True)
+
+
 class DefaultLayers(Service):
     """DefaultLayers Class.
 
@@ -1782,10 +1867,10 @@ class ImageTileProvider(Provider):
     attribution: string
         Tiles service attribution.
     """
-    
+
     _view_name = Unicode("ImageTileProviderView").tag(sync=True)
     _model_name = Unicode("ImageTileProviderModel").tag(sync=True)
-    
+
     url = Unicode().tag(sync=True)
     min_zoom = Int(default_value=0).tag(sync=True)
     max_zoom = Int(default_value=22).tag(sync=True)
@@ -1878,12 +1963,28 @@ class Map(DOMWidget, InteractMixin):
             raise Exception("layer already on map: %r" % layer)
         self.layers = tuple([l for l in self.layers] + [layer])
 
+    def add_layers(self, layers):
+        """Add layers to map."""
+        for layer in layers:
+            if layer.model_id in self._layer_ids:
+                raise Exception("layer already on map: %r" % layer)
+        self.layers = tuple([lr for lr in self.layers] + layers)
+
     def remove_layer(self, layer):
         """Remove layer from map."""
         if layer.model_id not in self._layer_ids:
             raise Exception("layer not on map: %r" % layer)
         self.layers = tuple([l for l in self.layers if l.model_id != layer.model_id])
 
+    def remove_layers(self, layers):
+        """Remove layers from map."""
+        for layer in layers:
+            if layer.model_id not in self._layer_ids:
+                raise Exception("layer not on map: %r" % layer)
+
+        remove_layer_ids = set([lr.model_id for lr in layers])
+        self.layers = tuple([lyr for lyr in self.layers if lyr.model_id not in remove_layer_ids])
+
     _object_ids = List()
 
     @validate("objects")
